@@ -9,7 +9,7 @@ void options(Process &process, Line &line, int argc, char **argv)
     {
         while (true)
         {
-            switch(int c =  getopt(argc, argv, "aAnNs:S:T:t:v:V:"))
+            switch(int c =  getopt(argc, argv, "aAnNs:S:T:t:V"))
             {
                 case 'A':
                     line.ignore();
@@ -44,6 +44,10 @@ void options(Process &process, Line &line, int argc, char **argv)
                     process.numberLines();
                 continue;
     
+                case 'V':
+                    process.noVerb();
+                continue;
+    
                 case -1:
                 throw true;             // ends option recognition
     
