@@ -2,5 +2,6 @@
 
 void Out::plainLine(std::string const &line)
 {
-    cout << d_indent << line << '\n';
+    nl();
+    cout << d_indent << line;
 }
